import {Image, Swiper, SwiperItem, View} from "@tarojs/components";
import {FC, useState} from "react";
import {AdwareType, HomeApi} from "@/api";
import Taro from "@tarojs/taro";
import styles from '../home.module.scss'

const Adware: FC = () => {
  const [data, setData] = useState<AdwareType[]>([])

  async function getAdware() {
    const res = await HomeApi.advert('home_space')
    setData(res)
  }

  function jumpAdware(url: string) {
    if (url.substring(0, 3) === 'wx:') {
      Taro.navigateTo({
        url: url.substring(3, url.length)
      })
    }
  }

  Taro.useLoad(getAdware)

  return (
    <View>
      {
        data.length === 1 && <Image
          src={data[0].image_url}
          mode='scaleToFill'
          lazyLoad
          fadeIn
          onClick={() => jumpAdware(data[0].image_path)}
          className={styles.adware}/>
      }
      {
        data.length > 1 && <Swiper
          indicatorDots
          autoplay
          circular
          indicatorActiveColor='rgba(255,255,255,0.5)'
          className={styles.adware}>
          {data.map(d => <SwiperItem key={d.id}>
            <Image
              src={d.image_url}
              mode='widthFix'
              lazyLoad
              fadeIn
              onClick={() => jumpAdware(d.image_path)}
              style={{width: "100%"}}/>
          </SwiperItem>)}
        </Swiper>
      }
    </View>
  )
}

export default Adware
